@@ -285,7 +285,7 @@ class Kubernetes(VaultApiBase):
         :param jwt: Signed JSON Web Token (JWT) from Kubernetes service account.
         :type jwt: str | unicode
         :param use_token: if True, uses the token in the response received from the auth request to set the "token"
-            attribute on the the :py:meth:`hvac.adapters.Adapter` instance under the _adapater Client attribute.
+            attribute on the the :py:meth:`hvac.adapters.Adapter` instance under the _adapter Client attribute.
         :type use_token: bool
         :param mount_point: The "path" the kubernetes auth method was mounted on.
         :type mount_point: str | unicode
